Installation — Django Hordak 1.0 documentation

# Installation

Installation using pip:

    pip install django-hordak

Add to installed apps:

    INSTALLED_APPS = [
        ...
        'mptt',
        'hordak',
    ]

Note

Hordak uses django-mptt to provide the account tree structure. It must therefore be listed in `INSTALLED_APPS` as shown above.

Run the migrations:

    ./manage.py migrate

You should now be able to import from Hordak:

    from hordak.models import Account, Transaction, ...